[![DOI](https://zenodo.org/badge/366323997.svg)](https://zenodo.org/badge/latestdoi/366323997)

# HOGBEN
**H**olistic **O**ptimization for **G**aining **B**etter **E**vidence from **N**eutrons

## About the Project
**For the original repositories that this work is based on, see [fisher-information](https://github.com/James-Durant/fisher-information) and [experimental-design](https://github.com/James-Durant/experimental-design)**.

Using the Fisher information (FI), the design of neutron reflectometry experiments can be optimised, leading to greater confidence in parameters of interest and better use of experimental time. This package contains modules and data for optimising the design of a wide range of reflectometry experiments.

Please refer to the [notebooks](https://github.com/jfkcooper/HOGBEN/tree/main/notebooks) for an introduction on how to use the code.


This repository is named after Lancelot Hogben, whose relentless opposition of eugenics (and vocal criticism of Ronald Fisher's views on it) we applaud.

### Citation
Please cite the following [article](https://arxiv.org/abs/2108.05605) if you intend on including elements of this work in your own publications:
> Durant, J. H., Wilkins, L. and Cooper, J. F. K. Optimising experimental design in neutron reflectometry. arXiv:2108.05605 (2021).

Or with BibTeX as:
```
@misc{Durant2021,
   title         = {Optimising experimental design in neutron reflectometry}, 
   author        = {Durant, J. H. and Wilkins, L. and Cooper, J. F. K.},
   year          = {2021},
   eprint        = {2108.05605},
   archivePrefix = {arXiv},
   primaryClass  = {physics.data-an}
}
```

## Contact
Jos Cooper - jos.cooper@stfc.ac.uk \
James Durant - james.durant@warwick.ac.uk \
Lucas Wilkins - lucas@lucaswilkins.com

## Acknowledgements
We thank Luke Clifton for his assistance and expertise in fitting the lipid monolayer and lipid bilayer data sets.

## License
Distributed under the BSD 3-Clause License. See [license](/LICENSE) for more information.
